#!/usr/bin/env python
# coding: utf-8

#########################################################################
#########################################################################

"""
   File Name: _cext.pyx
      Author: Wan Ji
      E-mail: wanji@live.com
  Created on: Wed Nov  5 16:32:11 2014 CST
"""
DESCRIPTION = """
"""

# import both numpy and the Cython declarations for numpy
import numpy as np
cimport numpy as np

# use the Numpy-C-API from Cython
np.import_array()

# cdefine the signature of our c function
cdef extern from "cext.h":
    void sumidxtab_core_cfunc(const np.float32_t * D, const np.uint8_t * blk,
        int nsq, int ksub, int cur_num, np.float32_t * out)

# create the wrapper code, with numpy type annotations
def sumidxtab_core(np.ndarray[np.float32_t, ndim=2, mode="c"] D not None,
                   np.ndarray[np.uint8_t, ndim=2, mode="c"] blk not None):
    out = np.zeros(blk.shape[0], dtype=D.dtype)
    sumidxtab_core_cfunc(<np.float32_t*> np.PyArray_DATA(D),
                         <np.uint8_t*> np.PyArray_DATA(blk),
                         D.shape[0], D.shape[1], blk.shape[0],
                         <np.float32_t*> np.PyArray_DATA(out))
    return out



#!/usr/bin/env python
# coding: utf-8
"""
   File Name: setup.py
      Author: Wan Ji
      E-mail: wanji@live.com
  Created on: Tue Nov  4 08:55:15 2014 CST
 Description:
"""


try:
    from setuptools import setup, Extension
except ImportError:
    from distutils.core import setup, Extension

try:
    from pypandoc import convert
    read_md = lambda f: convert(f, 'rst')
except ImportError:
    print "warning: pypandoc module not found, DONOT convert Markdown to RST"
    read_md = lambda f: open(f, 'r').read()

import numpy
from Cython.Distutils import build_ext

setup(name='hdidx',
      version='0.0.6',
      author='WAN Ji',
      author_email='wanji@live.com',
      package_dir={'hdidx': 'src'},
      packages=['hdidx'],

      cmdclass={'build_ext': build_ext},
      ext_modules=[Extension("hdidx._cext",
                             sources=[
                                 "cext/_cext.pyx",
                                 "cext/cext.c",
                             ],
                             include_dirs=[numpy.get_include(), "cext"])],

      scripts=[
          'tests/test_indexer.py',
          'tests/test_cext.py',
      ],
      url='https://github.com/wanji/hdidx',
      # license='LICENSE.txt',
      description='ANN Search in High-Dimensional Spaces',

      long_description=read_md("DESC.md"),
      install_requires=[
          "numpy      >= 1.6.0",
          "scipy      >= 0.9.0",
          "bottleneck >= 0.8.0",
          "lmdb       >= 0.83",
      ],
      )
